@@ -1,5 +1,5 @@
 package Mojolicious::Plugin::Yancy;
-our $VERSION = '0.022';
+our $VERSION = '0.023';
 # ABSTRACT: Embed a simple admin CMS into your Mojolicious application
 
 #pod =head1 SYNOPSIS
@@ -500,22 +500,23 @@ sub _build_openapi_spec {
                 },
                 parameters => [
                     {
-                        name => 'limit',
+                        name => '$limit',
                         type => 'integer',
                         in => 'query',
                         description => 'The number of items to return',
                     },
                     {
-                        name => 'offset',
+                        name => '$offset',
                         type => 'integer',
                         in => 'query',
                         description => 'The index (0-based) to start returning items',
                     },
                     {
-                        name => 'order_by',
+                        name => '$order_by',
                         type => 'string',
                         in => 'query',
                         pattern => '^(?:asc|desc):[^:,]+$',
+                        description => 'How to sort the list. A string containing one of "asc" (to sort in ascending order) or "desc" (to sort in descending order), followed by a ":", followed by the field name to sort by.',
                     },
                 ],
                 responses => {
@@ -715,7 +716,7 @@ Mojolicious::Plugin::Yancy - Embed a simple admin CMS into your Mojolicious appl
 
 =head1 VERSION
 
-version 0.022
+version 0.023
 
 =head1 SYNOPSIS
 
