@@ -1,5 +1,5 @@
 package Yancy::Backend::Mysql;
-our $VERSION = '0.022';
+our $VERSION = '0.023';
 # ABSTRACT: A backend for MySQL using Mojo::mysql
 
 #pod =head1 SYNOPSIS
@@ -124,9 +124,9 @@ sub create {
     my ( $self, $coll, $params ) = @_;
     my $id_field = $self->collections->{ $coll }{ 'x-id-field' } || 'id';
     my $id = $self->mysql->db->insert( $coll, $params )->last_insert_id;
-    # If we don't get an auto-incremented id or an exception, trust the
-    # ID was inserted correctly
-    return $id || $params->{ $id_field };
+    # Assume the id field is correct in case we're using a different
+    # unique ID (not the auto-increment column).
+    return $params->{ $id_field } || $id;
 }
 
 sub get {
@@ -266,7 +266,7 @@ Yancy::Backend::Mysql - A backend for MySQL using Mojo::mysql
 
 =head1 VERSION
 
-version 0.022
+version 0.023
 
 =head1 SYNOPSIS
 
