@@ -1,5 +1,5 @@
 package Yancy::Controller::Yancy::API;
-our $VERSION = '0.022';
+our $VERSION = '0.023';
 # ABSTRACT: An OpenAPI REST controller for the Yancy editor
 
 #pod =head1 DESCRIPTION
@@ -46,7 +46,7 @@ use Mojo::Base 'Mojolicious::Controller';
 #pod =method list_items
 #pod
 #pod List the items in a collection. The collection name should be in the
-#pod stash key C<collection>. C<limit>, C<offset>, and C<order_by> may be
+#pod stash key C<collection>. C<$limit>, C<$offset>, and C<$order_by> may be
 #pod provided as query parameters.
 #pod
 #pod =cut
@@ -56,14 +56,14 @@ sub list_items {
     return unless $c->openapi->valid_input;
     my $args = $c->validation->output;
     my %opt = (
-        limit => $args->{limit},
-        offset => $args->{offset},
+        limit => $args->{'$limit'},
+        offset => $args->{'$offset'},
     );
-    if ( $args->{order_by} ) {
+    if ( $args->{'$order_by'} ) {
         $opt{order_by} = [
             map +{ "-$_->[0]" => $_->[1] },
             map +[ split /:/ ],
-            split /,/, $args->{order_by}
+            split /,/, $args->{'$order_by'}
         ];
     }
     return $c->render(
@@ -159,7 +159,7 @@ Yancy::Controller::Yancy::API - An OpenAPI REST controller for the Yancy editor
 
 =head1 VERSION
 
-version 0.022
+version 0.023
 
 =head1 DESCRIPTION
 
@@ -171,7 +171,7 @@ backend data. This API is used by the Yancy editor.
 =head2 list_items
 
 List the items in a collection. The collection name should be in the
-stash key C<collection>. C<limit>, C<offset>, and C<order_by> may be
+stash key C<collection>. C<$limit>, C<$offset>, and C<$order_by> may be
 provided as query parameters.
 
 =head2 add_item
