@@ -23,9 +23,13 @@ sub new {
 sub create {
     my ( $self, $coll, $params ) = @_;
     my $id_field = $self->{collections}{ $coll }{ 'x-id-field' } || 'id';
-    if ( !$params->{ $id_field } ) {
-        my $id = ( max( keys %{ $COLLECTIONS{ $coll } } ) // 0 ) + 1;
-        $params->{ $id_field } = $id;
+    if ( !$params->{ $id_field } || $id_field ne 'id' ) {
+        my @existing_ids = $id_field eq 'id'
+            ? keys %{ $COLLECTIONS{ $coll } }
+            : map { $_->{ id } } values %{ $COLLECTIONS{ $coll } }
+            ;
+        my $id = ( max( @existing_ids ) // 0 ) + 1;
+        $params->{ $id_field ne 'id' ? 'id' : $id_field } = $id;
     }
     $COLLECTIONS{ $coll }{ $params->{ $id_field } } = $params;
     return $params->{ $id_field };
