@@ -5,7 +5,8 @@ CREATE TABLE people (
     `email` VARCHAR(255)
 );
 CREATE TABLE `user` (
-    `username` VARCHAR(255) PRIMARY KEY,
+    id INTEGER AUTO_INCREMENT PRIMARY KEY,
+    `username` VARCHAR(255) UNIQUE NOT NULL,
     `email` VARCHAR(255) NOT NULL,
     `password` VARCHAR(255) NOT NULL,
     `access` ENUM ( 'user', 'moderator', 'admin' ) NOT NULL DEFAULT 'user'
